@@ -9,12 +9,11 @@ import (
 	"github.com/spf13/pflag"
 
 	"k8s.io/kubectl/pkg/util/templates"
-	"k8s.io/kubernetes/test/e2e/lifecycle"
 	"k8s.io/kubernetes/test/e2e/upgrades"
 
 	"github.com/openshift/origin/pkg/test/ginkgo"
 	"github.com/openshift/origin/test/e2e/upgrade"
-	exutil "github.com/openshift/origin/test/extended/util"
+	"github.com/openshift/origin/test/extended/util/disruption/controlplane"
 )
 
 // upgradeSuites are all known upgade test suites this binary should run
@@ -25,7 +24,7 @@ var upgradeSuites = []*ginkgo.TestSuite{
 		Run all tests.
 		`),
 		Matches: func(name string) bool {
-			return strings.Contains(name, "[Feature:ClusterUpgrade]") && strings.Contains(name, "[Suite:openshift]")
+			return strings.Contains(name, "[Feature:ClusterUpgrade]") && !strings.Contains(name, "[Suite:k8s]")
 		},
 		Init: func(opt map[string]string) error {
 			return upgradeInitArguments(opt, func(string) bool { return true })
@@ -38,10 +37,12 @@ var upgradeSuites = []*ginkgo.TestSuite{
 		Run only the tests that verify the platform remains available.
 		`),
 		Matches: func(name string) bool {
-			return strings.Contains(name, "[Feature:ClusterUpgrade]") && strings.Contains(name, "[Suite:openshift]")
+			return strings.Contains(name, "[Feature:ClusterUpgrade]") && !strings.Contains(name, "[Suite:k8s]")
 		},
 		Init: func(opt map[string]string) error {
-			return upgradeInitArguments(opt, func(name string) bool { return name == "control-plane-available" })
+			return upgradeInitArguments(opt, func(name string) bool {
+				return name == controlplane.NewKubeAvailableTest().Name() || name == controlplane.NewKubeAvailableTest().Name()
+			})
 		},
 		TestTimeout: 240 * time.Minute,
 	},
@@ -100,30 +101,30 @@ func (o *UpgradeOptions) ToEnv() string {
 	return string(out)
 }
 
-func initUpgrade(value string) error {
-	if len(value) == 0 {
-		return nil
-	}
+func initUpgrade(value string) (*UpgradeOptions, error) {
 	var opt UpgradeOptions
+	if len(value) == 0 {
+		return &opt, nil
+	}
 	if err := json.Unmarshal([]byte(value), &opt); err != nil {
-		return err
+		return nil, err
 	}
 	for _, suite := range upgradeSuites {
 		if suite.Name == opt.Suite {
-			lifecycle.SetUpgradeTarget("")
-			lifecycle.SetUpgradeImage(opt.ToImage)
-			exutil.TestContext.ReportDir = opt.JUnitDir
 			o, err := opt.OptionsMap()
 			if err != nil {
-				return err
+				return nil, err
 			}
 			if suite.Init != nil {
-				return suite.Init(o)
+				if err := suite.Init(o); err != nil {
+					return nil, err
+				}
 			}
-			return nil
+			upgrade.SetToImage(opt.ToImage)
+			return &opt, nil
 		}
 	}
-	return fmt.Errorf("unrecognized upgrade info")
+	return nil, fmt.Errorf("unrecognized upgrade info")
 }
 
 func filterUpgrade(tests []upgrades.Test, match func(string) bool) error {
